@@ -1,8 +1,10 @@
 #' Calculates the ICV of a covariance matrix.
 #'
-#' Calculates the coefficient of variation of the eigenvalues of a covariance matrix, a measure of 
+#' Calculates the coefficient of variation of the eigenvalues of a covariance matrix, a measure of
 #' integration comparable to the R^2 in correlation matrices.
 #'
+#' Warning: CalcEigenVar is strongly preferred and should probably be used in place of this function.
+#'
 #' @param cov.matrix Covariance matrix.
 #' @return coefficient of variation of the eigenvalues of a covariance matrix
 #' @export
@@ -17,9 +19,10 @@
 #' @keywords integration
 
 CalcICV <- function (cov.matrix){
+  .Deprecated("CalcEigenVar", package=NULL, "CalcICV is deprecated. CalcEigenVar is strongly preferred and should be used instead.")
   if(!isSymmetric(cov.matrix)) stop("covariance matrix must be symmetric.")
   if(sum(diag(cov.matrix)) == dim(cov.matrix)[1]) warning("Matrix appears to be a correlation matrix! Only covariance matrices should be used for ICV.")
   eVals <- eigen(cov.matrix, only.values = TRUE)$values
   ICV <- sd(eVals)/mean(eVals)
   return (ICV)
-}
\ No newline at end of file
+}
