@@ -11,7 +11,7 @@
 #' @importFrom methods is
 #' @importFrom stats anova confint cor cor.test cov cov2cor lm mahalanobis princomp quantile reorder residuals rnorm runif sd var
 #' @importFrom utils write.csv write.table
-NULL
+"_PACKAGE"
 
 #' Linear distances for five mouse lines
 #'
@@ -31,7 +31,7 @@ NULL
 #' @references Penna, A., Melo, D., Bernardi, S., Oyarzabal, M.I. and Marroig, G. (2017), The evolution of phenotypic integration: How directional selection reshapes covariation in mice. Evolution, 71: 2370-2380. https://doi.org/10.1111/evo.13304
 #' (\href{https://pubmed.ncbi.nlm.nih.gov/28685813/}{PubMed})
 #'
-#' @source \href{https://datadryad.org/stash/dataset/doi:10.5061/dryad.5gr8r}{Dryad Archive}
+#' @source \href{https://datadryad.org/dataset/doi:10.5061/dryad.5gr8r}{Dryad Archive}
 #'
 #' @examples
 #' data(ratones)
